"""
Screen Test: Tests the methods in the Screen class
"""

import unittest;
from pydraw import Screen, Color, Rectangle;


class ScreenTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls) -> None:
        cls.screen = Screen(800, 600, 'Custom Name');

    def test_color(self):
        self.screen.color(Color('red'))
        self.assertEqual(self.screen.color(), Color('red'));

    def test_helpers(self):
        self.screen.toggle_grid();
        self.screen.clear();
        self.screen.grid(helpers=True);
        self.assertNotEqual(len(self.screen.gridlines()), len(self.screen.objects()));

    def test_objects(self):
        rect = Rectangle(self.screen, self.screen.width() / 2 - 25, self.screen.height() / 2 - 25, 50, 50);
        self.assertEqual(self.screen.width(), 800);
        self.assertEqual(self.screen.height(), 600);

        self.assertEqual(rect.x(), 375);
        self.assertEqual(rect.y(), 275);

        self.assertEqual(len(self.screen.objects()), 1);
        self.assertEqual(self.screen.objects()[0].color(), rect.color());
        self.assertEqual(self.screen.objects()[0], rect);
        self.assertEqual(len(self.screen.gridlines()), 26);

        self.screen.remove(rect);


if __name__ == '__main__':
    unittest.main();



from pydraw import *;

screen = Screen(800, 600);

screen.toggle_grid();
# screen.clear();
screen.grid(helpers=True);


p1 = Polygon(screen, 5, 150, 50, 50, 50)
poly = Triangle(screen, 50, 50, 50, 50);
image = Image(screen, '../images/pacman.gif', 100, 50, 50, 50);
image.load();

# poly.width(500, ratio=True)


def keydown(key):
    if key == 'r':
        p1.rotate(1);
    elif key == 'w':
        p1.width(p1.width() + 10)
    elif key == 'h':
        p1.height(p1.height() + 10)
    elif key == 'x':
        p1.x(p1.x() + 10)
    elif key == 'y':
        p1.y(p1.y() + 10)
    elif key == 'g':
        image.next();


screen.listen();

fps = 30;
running = True;
while running:
    screen.update();
    screen.sleep(1 / fps);



"""
CustomPolygon Test: Tests methods in the CustomPolygon class.
"""

import unittest;
from pydraw import Screen, Color, Location, Renderable, CustomRenderable, CustomPolygon;


class PolygonTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls) -> None:
        cls.screen = Screen(800, 600);

    def test_creation(self):
        polygon = CustomPolygon(self.screen,
                                     [(150, 150), (250, 150), (300, 200), (300, 250), (250, 230), (150, 300)],
                                     Color('red'), Color('black'), True);

        self.assertEqual(polygon.vertices(), [(150, 150), (250, 150), (300, 200), (300, 250), (250, 230), (150, 300)]);

    def test_methods(self):
        polygon = CustomPolygon(self.screen,
                                [(150, 150), (250, 150), (300, 200), (300, 250), (250, 230), (150, 300)]);

        self.assertEqual(polygon.location(), (150, 150));
        polygon.move(-50, 200);
        self.assertEqual(polygon.location(), (100, 350));
        polygon.moveto(x=550);
        self.assertEqual(polygon.location(), (550, 350));

        self.assertEqual(polygon.width(), 150);
        self.assertEqual(polygon.height(), 150);

        self.assertEqual(polygon.rotation(), 0);
        polygon.rotate(25);
        self.assertEqual(polygon.rotation(), 25);
        polygon.rotation(-25);
        self.assertEqual(polygon.rotation(), -25);

        self.assertEqual(polygon.color(), Color('black'));
        self.assertEqual(polygon.border(), Color.NONE);

        # self.assertEqual(polygon.transform(), (150, 150, -25));
        # TODO: Polygon keeps original vertices and modifies shape upon update (width/height transform + rotation)


if __name__ == '__main__':
    unittest.main();



"""
Location Test: Tests methods in the Location class
"""

import unittest;
from pydraw import Screen, Location, Rectangle;
from pydraw.errors import *;


class LocationTest(unittest.TestCase):

    def test_creation(self):
        location1 = Location(150, 300);
        location2 = Location((150, 300));
        location3 = Location(location2);

        location4 = Location(x=150, y=300);
        location5 = Location(x=150);

        self.assertEqual(location1, location2);
        self.assertEqual(location2, location3);
        self.assertEqual(location3, location4);
        self.assertEqual(location5.x(), 150);
        self.assertEqual(location5.y(), 0);

    def test_methods(self):
        location1 = Location(150, 300);
        self.assertEqual(location1, (150, 300));

        location1.move(dx=100, dy=50);
        self.assertEqual(location1, (250, 350));

        self.assertRaises(InvalidArgumentError, location1.move, '');

        location1.moveto((300, 300));
        self.assertEqual(location1, (300, 300));
        location1.moveto(x=500);
        self.assertEqual(location1, (500, 300));


if __name__ == '__main__':
    unittest.main();
